<div style="text-align: left; margin-bottom: 20px;">
  <img src="https://kiss-ai-stack.github.io/kissaistack.svg" alt="KISS AI Stack Banner" style="max-width: auto; height: 250px">
</div>

# kiss-ai-stack - types

Common types for kiss-ai-stack's Python components.

To install,

```python
pip install kiss-ai-stack-types
```

### License

This library is licensed under the MIT License - see the [LICENSE](./LICENSE) file for details.
